==> commoncpp2-1.1.0.tar.gz: commoncpp2-1.1.0/tests/bug1.cpp <==
// Copyright (C) 1999-2001 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// As a special exception to the GNU General Public License, permission is 
// granted for additional uses of the text contained in its release 
// of APE.
// 
// The exception is that, if you link the APE library with other files
// to produce an executable, this does not by itself cause the
// resulting executable to be covered by the GNU General Public License.
// Your use of that executable is in no way restricted on account of
// linking the APE library code into it.
//
// This exception does not however invalidate any other reasons why
// the executable file might be covered by the GNU General Public License.
//
// This exception applies only to the code released under the 
// name APE.  If you copy code from other releases into a copy of
// APE, as the General Public License permits, the exception does
// not apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
//
// If you write modifications of your own for APE, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice.

#include <cc++/thread.h>
#include <iostream>
#include <cstdio>

// This was a test case for a bug report related to the final self-
// deleting the thread.

#ifdef	CCXX_NAMESPACES
using namespace std;
using namespace ost;
#endif

class ThreadTest : public Thread
{
private:
	void run() { cout << "Run()..." << endl;};
	void final() { cout << "Final()..." << endl; delete this;};
};

int main()
{
	ThreadTest *thread = new ThreadTest;
	cout << "before start()..." << endl;
//	printf("THREAD is %p\n", thread); not useful in reg test
	thread->start();
	Thread::sleep(5000);
	cout << "exiting..." << endl;
	// do not delete thread, already deleted in method Final
	return 0;
}

==> commoncpp2-1.3.19.tar.gz: commoncpp2-1.3.19/tests/bug1.cpp <==
// Copyright (C) 1999-2001 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// As a special exception to the GNU General Public License, permission is 
// granted for additional uses of the text contained in its release 
// of APE.
// 
// The exception is that, if you link the APE library with other files
// to produce an executable, this does not by itself cause the
// resulting executable to be covered by the GNU General Public License.
// Your use of that executable is in no way restricted on account of
// linking the APE library code into it.
//
// This exception does not however invalidate any other reasons why
// the executable file might be covered by the GNU General Public License.
//
// This exception applies only to the code released under the 
// name APE.  If you copy code from other releases into a copy of
// APE, as the General Public License permits, the exception does
// not apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
//
// If you write modifications of your own for APE, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice.

#include <cc++/thread.h>
#include <iostream>
#include <cstdio>

// This was a test case for a bug report related to the final self-
// deleting the thread.

#ifdef	CCXX_NAMESPACES
using namespace std;
using namespace ost;
#endif

class ThreadTest : public Thread
{
private:
	void run() { cout << "Run()..." << endl;};
	void final() { cout << "Final()..." << endl;};
};

int main()
{
	ThreadTest *thread = new ThreadTest;
	cout << "before start()..." << endl;
//	printf("THREAD is %p\n", thread); not useful in reg test
	thread->start();
	Thread::sleep(5000);
	cout << "exiting..." << endl;
	// do not delete thread, already deleted in method Final
	return 0;
}
